==> parser-generator-cc-1.0.2-sources.jar: com/helger/pgcc/output/java/JavaResourceTemplateLocationImpl.java <==
/**
 * Copyright 2017-2018 Philip Helger, pgcc@helger.com
 *
 * Copyright 2011 Google Inc. All Rights Reserved.
 * Author: sreeni@google.com (Sreeni Viswanadha)
 *
 * Copyright (c) 2006, Sun Microsystems, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Sun Microsystems, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.helger.pgcc.output.java;

public final class JavaResourceTemplateLocationImpl implements IJavaResourceTemplateLocations
{
  public String getTokenTemplateResourceUrl ()
  {
    return "/templates/Token.template";
  }

  public String getTokenManagerTemplateResourceUrl ()
  {
    return "/templates/TokenManager.template";
  }

  public String getTokenMgrErrorTemplateResourceUrl ()
  {
    return "/templates/TokenMgrError.template";
  }

  public String getJavaCharStreamTemplateResourceUrl ()
  {
    return "/templates/JavaCharStream.template";
  }

  public String getCharStreamTemplateResourceUrl ()
  {
    return "/templates/CharStream.template";
  }

  public String getSimpleCharStreamTemplateResourceUrl ()
  {
    return "/templates/SimpleCharStream.template";
  }

  public String getParseExceptionTemplateResourceUrl ()
  {
    return "/templates/ParseException.template";
  }

}

==> parser-generator-cc-1.1.1-sources.jar: com/helger/pgcc/output/java/JavaResourceTemplateLocationImpl.java <==
/**
 * Copyright 2017-2019 Philip Helger, pgcc@helger.com
 *
 * Copyright 2011 Google Inc. All Rights Reserved.
 * Author: sreeni@google.com (Sreeni Viswanadha)
 *
 * Copyright (c) 2006, Sun Microsystems, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *     * Redistributions of source code must retain the above copyright notice,
 *       this list of conditions and the following disclaimer.
 *     * Redistributions in binary form must reproduce the above copyright
 *       notice, this list of conditions and the following disclaimer in the
 *       documentation and/or other materials provided with the distribution.
 *     * Neither the name of the Sun Microsystems, Inc. nor the names of its
 *       contributors may be used to endorse or promote products derived from
 *       this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */
package com.helger.pgcc.output.java;

public class JavaResourceTemplateLocationImpl implements IJavaResourceTemplateLocations
{
  public String getTokenTemplateResourceUrl ()
  {
    return "/templates/Token.template";
  }

  public String getTokenManagerTemplateResourceUrl ()
  {
    return "/templates/TokenManager.template";
  }

  public String getTokenMgrErrorTemplateResourceUrl ()
  {
    return "/templates/TokenMgrError.template";
  }

  public String getCharStreamTemplateResourceUrl ()
  {
    return "/templates/stream/java/CharStream.template";
  }

  public String getAbstractCharStreamTemplateResourceUrl ()
  {
    return "/templates/stream/java/AbstractCharStream.template";
  }

  public String getJavaCharStreamTemplateResourceUrl ()
  {
    return "/templates/stream/java/JavaCharStream.template";
  }

  public String getSimpleCharStreamTemplateResourceUrl ()
  {
    return "/templates/stream/java/SimpleCharStream.template";
  }

  public String getParseExceptionTemplateResourceUrl ()
  {
    return "/templates/ParseException.template";
  }
}
